==> makeen-expressionengine-0.0.51.tgz: package/src/functions/aggregates/sum.ts <==
﻿import { aggregateFunction } from './../aggregateFunction'
import expressionData from '../../expressionData'
import { expressionPart } from './../../compiler/parts/expressionPart'
import { List } from 'typescript-dotnet-commonjs/System/Collections/List'
import { } from 'typescript-dotnet-commonjs/System/Types'
import { outputVariables } from '../../utils/outputVariables'
import { isFloatType } from '../../utils/general'
export class sum extends aggregateFunction {

    public invokeIteration(expressionData: expressionData, current: Object, running: Object, parameters: List<expressionPart>, /* out */resolved: outputVariables): Object {
        resolved.resolved = true;
        if ((current != null)) {
            if ((typeof current == 'string')) {
                return (Number.parseFloat(current)) + (running != null ? (running as number) : 0);
            }
            else if (typeof current == 'boolean') {
                return (((current) ? 1 : 0) + ((running != null ? ((running as boolean) ? 1 : 0) : 0))) > 0 ? true : false;

            }
            // else if ((current instanceof  byte)) {
            //     return ((<number>(current)) + (<number>(running)));
            //     // TODO: Warning!!!, inline IF is not supported ?
            //     (running != null);
            //     0;
            // }
            else if (typeof current == 'number' && !isFloatType(current)) {
                return (current) + (running != null ? (running as number) : 0);

            }

            else if (typeof current == 'number' && isFloatType(current)) {
                return (current) + (running != null ? (running as number) : 0);

            }
        }

        return running != null ? running : 0;

    }
}

==> makeen-expressionengine-0.0.63.tgz: package/src/functions/aggregates/sum.ts <==
﻿import { aggregateFunction } from './../aggregateFunction'
import expressionData from '../../expressionData'
import { expressionPart } from './../../compiler/parts/expressionPart'
import { List } from 'typescript-dotnet-commonjs/System/Collections/List'
import { } from 'typescript-dotnet-commonjs/System/Types'
import { outputVariables } from '../../utils/outputVariables'
import { isFloatType } from '../../utils/general'
export class sum extends aggregateFunction {

     invokeIteration(expressionData: expressionData, current: Object, running: Object, parameters: expressionPart[], /* out */resolved: outputVariables): Object {
        resolved.resolved = true;
        if ((current != null)) {
            if ((typeof current == 'string')) {
                return (Number.parseFloat(current)) + (running != null ? (running as number) : 0);
            }
            else if (typeof current == 'boolean') {
                return (((current) ? 1 : 0) + ((running != null ? ((running as boolean) ? 1 : 0) : 0))) > 0 ? true : false;

            }
            // else if ((current instanceof  byte)) {
            //     return ((<number>(current)) + (<number>(running)));
            //     // TODO: Warning!!!, inline IF is not supported ?
            //     (running != null);
            //     0;
            // }
            else if (typeof current == 'number' && !isFloatType(current)) {
                return (current) + (running != null ? (running as number) : 0);

            }

            else if (typeof current == 'number' && isFloatType(current)) {
                return (current) + (running != null ? (running as number) : 0);

            }
        }

        return running != null ? running : 0;

    }
}
